DEFAULT_OUTPUT_PATH = "prompter"
DEFAULT_CONFIG_PATH = "nprompter.toml"
DEFAULT_PROPERTY = "Status"
DEFAULT_VALUE = "Ready"
DEFAULT_PORT = 8889
